@@ -1,5 +1,5 @@
 package Data::Xslate;
-$Data::Xslate::VERSION = '0.02';
+$Data::Xslate::VERSION = '0.03';
 =head1 NAME
 
 Data::Xslate - Templatize your data.
@@ -25,11 +25,18 @@ Data::Xslate - Templatize your data.
         },
     );
     
-    # This would produce the following:
-    # $data->{email} = {
-    #     to => 'john@example.com',
-    #     from => 'george@example.com',
-    #     subject => 'Hello John!',
+    # The above produces the following:
+    # $data = {
+    #     user => {
+    #         login => 'john',
+    #         email => 'john@example.com',
+    #         name  => 'John',
+    #     },
+    #     email => {
+    #         to      => 'john@example.com',
+    #         from    => 'george@example.com',
+    #         subject => 'Hello John!',
+    #     },
     # }
 
 =head1 DESCRIPTION
@@ -45,6 +52,7 @@ use Text::Xslate;
 use Types::Standard -types;
 use Types::Common::String -types;
 use Carp qw( croak );
+use Storable qw( freeze thaw );
 
 use Moo;
 use strictures 2;
@@ -206,6 +214,8 @@ our $PATH_FOR_XSLATE;
 sub render {
     my ($self, $data) = @_;
 
+    $data = thaw( freeze( $data ) );
+
     local $Carp::Internal{ (__PACKAGE__) } = 1;
 
     local $XSLATE = $self->_xslate();
@@ -367,7 +377,7 @@ __END__
 =head1 TEMPLATING
 
 The most powerful feature by far is templating, where you can
-use L<Text::Xslate> in you values.
+use L<Text::Xslate> in your values.
 
     {
         foo => 'green',
@@ -461,7 +471,7 @@ a key path such as C<bar.0> you are looking for a hash with the C<bar>
 key whose value is an array, and then the first value in the array is
 fetched.
 
-Note that the above example assume that L</key_separator> is a dot (C<.>),
+Note that the above examples assume that L</key_separator> is a dot (C<.>),
 the default.
 
 =head1 SCOPE
